@@ -1,9 +1,10 @@
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 
 from openpyxl.compat.numbers import NUMPY, PANDAS
-from openpyxl.xml import LXML
+from openpyxl.xml import DEFUSEDXML, LXML
 from openpyxl.workbook import Workbook
+from openpyxl.reader.excel import load_workbook as open
 from openpyxl.reader.excel import load_workbook
 import openpyxl._constants as constants
 
