@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 """Manage individual cells in a spreadsheet.
 
@@ -15,35 +15,15 @@ from copy import copy
 import datetime
 import re
 
-from itertools import islice, product
 
 from openpyxl.compat import (
     NUMERIC_TYPES,
     deprecated,
 )
-from openpyxl.utils.units import (
-    DEFAULT_ROW_HEIGHT,
-    DEFAULT_COLUMN_WIDTH
-)
-from openpyxl.utils.datetime  import (
-    to_excel,
-    time_to_days,
-    timedelta_to_days,
-    from_excel
-    )
-from openpyxl.utils.exceptions import (
-    IllegalCharacterError
-)
-from openpyxl.utils.units import points_to_pixels
-from openpyxl.utils import (
-    get_column_letter,
-    column_index_from_string,
-)
-from openpyxl.utils.inference import (
-    cast_numeric,
-    cast_percentage,
-    cast_percentage,
-)
+
+from openpyxl.utils.exceptions import IllegalCharacterError
+
+from openpyxl.utils import get_column_letter
 from openpyxl.styles import numbers, is_date_format
 from openpyxl.styles.styleable import StyleableObject
 from openpyxl.worksheet.hyperlink import Hyperlink
@@ -160,9 +140,6 @@ class Cell(StyleableObject):
     def base_date(self):
         return self.parent.parent.epoch
 
-    @property
-    def guess_types(self):
-        return getattr(self.parent.parent, 'guess_types', False)
 
     def __repr__(self):
         return "<Cell {0!r}.{1}>".format(self.parent.title, self.coordinate)
