@@ -1,6 +1,5 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
-from openpyxl.compat import unicode
+# Copyright (c) 2010-2020 openpyxl
+
 
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
@@ -13,7 +12,7 @@ class AuthorList(Serialisable):
 
     tagname = "authors"
 
-    author = Sequence(expected_type=unicode)
+    author = Sequence(expected_type=str)
     authors = Alias("author")
 
     def __init__(self,
