@@ -1,8 +1,6 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 ## Incomplete!
-
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.descriptors import (
     Typed,
@@ -20,29 +18,12 @@ from openpyxl.xml.constants import SHEET_MAIN_NS
 from openpyxl.xml.functions import tostring
 
 from openpyxl.cell.text import Text
+#from openpyxl.worksheet.ole import ObjectAnchor
 from .author import AuthorList
 from .comments import Comment
 from .shape_writer import ShapeWriter
 
 
-class ObjectAnchor(Serialisable):
-
-    moveWithCells = Bool(allow_none=True)
-    sizeWithCells = Bool(allow_none=True)
-    #z-order = Integer(allow_none=True) needs alias
-    #from
-    #to defs from xdr
-
-    def __init__(self,
-                 moveWithCells=None,
-                 sizeWithCells=None,
-                 #z-order=None,
-                ):
-        self.moveWithCells = moveWithCells
-        self.sizeWithCells = sizeWithCells
-        #self.z-order = z-order
-
-
 class Properties(Serialisable):
 
     locked = Bool(allow_none=True)
@@ -60,7 +41,7 @@ class Properties(Serialisable):
     autoScale = Bool(allow_none=True)
     rowHidden = Bool(allow_none=True)
     colHidden = Bool(allow_none=True)
-    anchor = Typed(expected_type=ObjectAnchor, )
+    #anchor = Typed(expected_type=ObjectAnchor, )
 
     __elements__ = ('anchor',)
 
@@ -123,6 +104,8 @@ class CommentRecord(Serialisable):
                  text=None,
                  commentPr=None,
                  author=None,
+                 height=79,
+                 width=144
                 ):
         self.ref = ref
         self.authorId = authorId
@@ -133,6 +116,8 @@ class CommentRecord(Serialisable):
         self.text = text
         self.commentPr = commentPr
         self.author = author
+        self.height = height
+        self.width = width
 
 
     @classmethod
@@ -144,6 +129,8 @@ class CommentRecord(Serialisable):
         ref = cell.coordinate
         self = cls(ref=ref, author=comment.author)
         self.text.t = comment.content
+        self.height = comment.height
+        self.width = comment.width
         return self
 
 
@@ -194,7 +181,7 @@ class CommentSheet(Serialisable):
         authors = self.authors.author
 
         for c in self.commentList:
-            yield c.ref, Comment(c.content, authors[c.authorId])
+            yield c.ref, Comment(c.content, authors[c.authorId], c.height, c.width)
 
 
     @classmethod
