@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 """
 File manifest
@@ -117,7 +117,7 @@ class Manifest(Serialisable):
         Map content types to file extensions
         Skip parts without extensions
         """
-        exts = set([os.path.splitext(part.PartName)[-1] for part in self.Override])
+        exts = {os.path.splitext(part.PartName)[-1] for part in self.Override}
         return [(ext[1:], mimetypes.types_map[True][ext]) for ext in sorted(exts) if ext]
 
 
