@@ -1,5 +1,4 @@
-from __future__ import absolute_import
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 # Simplified implementation of headers and footers: let worksheets have separate items
 
@@ -17,7 +16,7 @@ from openpyxl.descriptors import (
 )
 from openpyxl.descriptors.serialisable import Serialisable
 
-from openpyxl.compat import unicode
+
 from openpyxl.xml.functions import Element
 from openpyxl.utils.escape import escape, unescape
 
@@ -114,7 +113,6 @@ class _HeaderFooterPart(Strict):
     def __bool__(self):
         return bool(self.text)
 
-    __nonzero__ = __bool__
 
 
     @classmethod
@@ -181,7 +179,7 @@ class HeaderFooterItem(Strict):
         for key, part in zip(
             self.__keys, [self.left, self.center, self.right]):
             if part.text is not None:
-                txt.append(u"&{0}{1}".format(key, unicode(part)))
+                txt.append(u"&{0}{1}".format(key, str(part)))
         txt = "".join(txt)
         txt = SUBS_REGEX.sub(replace, txt)
         return escape(txt)
@@ -190,7 +188,6 @@ class HeaderFooterItem(Strict):
     def __bool__(self):
         return any([self.left, self.center, self.right])
 
-    __nonzero__ = __bool__
 
 
     def to_tree(self, tagname):
@@ -198,7 +195,7 @@ class HeaderFooterItem(Strict):
         Return as XML node
         """
         el = Element(tagname)
-        el.text = unicode(self)
+        el.text = str(self)
         return el
 
 
@@ -271,4 +268,3 @@ class HeaderFooter(Serialisable):
         parts = [getattr(self, attr) for attr in self.__attrs__ + self.__elements__]
         return any(parts)
 
-    __nonzero__ = __bool__
