@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2019 openpyxl
+# Copyright (c) 2010-2020 openpyxl
 
 """
 XML compatability functions
@@ -7,59 +7,39 @@ XML compatability functions
 # Python stdlib imports
 import re
 from functools import partial
-# compatibility
 
-# package imports
 from openpyxl import DEFUSEDXML, LXML
 
 if LXML is True:
     from lxml.etree import (
     Element,
-    ElementTree,
     SubElement,
     register_namespace,
     QName,
     xmlfile,
     XMLParser,
     )
-    from lxml.etree import XMLSyntaxError
-
-    if DEFUSEDXML is True:
-        from defusedxml.common import DefusedXmlException
-        from defusedxml.cElementTree import iterparse
-        from defusedxml.lxml import fromstring as _fromstring, tostring
-
-        def fromstring(*args, **kwargs):
-            try:
-                return _fromstring(*args, **kwargs)
-            except XMLSyntaxError as e:
-                raise DefusedXmlException(str(e))
-    else:
-        from lxml.etree import fromstring, tostring
-        from xml.etree.cElementTree import iterparse
-        # do not resolve entities
-        safe_parser = XMLParser(resolve_entities=False)
-        fromstring = partial(fromstring, parser=safe_parser)
+    from lxml.etree import fromstring, tostring
+    # do not resolve entities
+    safe_parser = XMLParser(resolve_entities=False)
+    fromstring = partial(fromstring, parser=safe_parser)
 
 else:
     from xml.etree.ElementTree import (
-    ElementTree,
     Element,
     SubElement,
     fromstring,
     tostring,
-    iterparse,
     QName,
     register_namespace
     )
-    if DEFUSEDXML is True:
-        from defusedxml.cElementTree import (
-        fromstring,
-        tostring,
-        iterparse,
-        )
     from et_xmlfile import xmlfile
+    if DEFUSEDXML is True:
+        from defusedxml.ElementTree import fromstring
 
+from xml.etree.ElementTree import iterparse
+if DEFUSEDXML is True:
+    from defusedxml.ElementTree import iterparse
 
 from openpyxl.xml.constants import (
     CHART_NS,
